pub struct Widget {
pub app_code: String,
pub environment: Option<String>,
}Expand description
Widget integration metadata.
Fields
app_code: StringApp code of the widget host.
environment: Option<String>Deployment environment of the widget.
Implementations
Sourceimpl Widget
impl Widget
Sourcepub fn new(app_code: impl Into<String>) -> Self
pub fn new(app_code: impl Into<String>) -> Self
Construct a new Widget for the given app code.
Used when an order originates from an embedded widget integration.
The app_code identifies the widget host application.
Parameters
app_code— the widget host’s application identifier.
Returns
A new Widget with environment set to None.
Example
use cow_rs::app_data::Widget;
let w = Widget::new("WidgetHost").with_environment("production");
assert_eq!(w.app_code, "WidgetHost");
assert!(w.has_environment());Sourcepub fn with_environment(self, env: impl Into<String>) -> Self
pub fn with_environment(self, env: impl Into<String>) -> Self
Sourcepub const fn has_environment(&self) -> bool
pub const fn has_environment(&self) -> bool
Returns true if a deployment environment string is set.