SolverCompetition

Struct SolverCompetition 

pub struct SolverCompetition {
    pub auction_id: Option<i64>,
    pub auction_start_block: Option<u64>,
    pub auction_deadline_block: Option<u64>,
    pub transaction_hashes: Option<Vec<String>>,
    pub auction: Option<CompetitionAuction>,
    pub solutions: Option<Vec<SolverSettlement>>,
}
Solver competition response from GET /api/v1/solver_competition/{auctionId}.

Contains the full details of which solvers participated, their proposed solutions, and which solution won the auction.

Fields

auction_id: Option<i64>

Auction ID this competition corresponds to.

auction_start_block: Option<u64>

Block at which the auction started.

auction_deadline_block: Option<u64>

Deadline block by which the auction must be settled.

transaction_hashes: Option<Vec<String>>

Transaction hashes for the winning solutions.

auction: Option<CompetitionAuction>

The orders and prices that made up the competition auction.

solutions: Option<Vec<SolverSettlement>>

All solutions submitted by solvers, in ascending score order.

Implementations

Source

impl SolverCompetition

pub const fn has_auction_id(&self) -> bool

Returns true if an auction ID is available.

pub const fn has_start_block(&self) -> bool

Returns true if the auction start block is available.

pub const fn has_deadline_block(&self) -> bool

Returns true if the auction deadline block is available.

pub fn is_settled(&self) -> bool

Returns true if there are on-chain settlement transaction hashes (indicating the competition has been settled on-chain).

pub const fn has_auction(&self) -> bool

Returns true if the competition auction data is available.

pub const fn has_solutions(&self) -> bool

Returns true if solver solutions are available.

pub fn num_solutions(&self) -> usize

Returns the number of solver solutions, or 0 if unavailable.

pub fn winning_solution(&self) -> Option<&SolverSettlement>

Returns a reference to the winning solution, if one exists.

Searches through all solutions and returns the first one where SolverSettlement::is_winner is true.

pub const fn has_transaction_hashes(&self) -> bool

Returns true if on-chain settlement transaction hashes are available.

This indicates the competition has been settled on-chain.