pub struct SolverExecution {
pub solver: String,
pub executed_sell_amount: Option<String>,
pub executed_buy_amount: Option<String>,
}Expand description
Per-solver execution amounts within the competition.
Fields
solver: StringSolver name.
executed_sell_amount: Option<String>Sell amount executed by this solver (if any).
executed_buy_amount: Option<String>Buy amount executed by this solver (if any).
Implementations
Sourceimpl SolverExecution
impl SolverExecution
Sourcepub const fn has_executed_sell_amount(&self) -> bool
pub const fn has_executed_sell_amount(&self) -> bool
Returns true if a sell execution amount is available.
Sourcepub const fn has_executed_buy_amount(&self) -> bool
pub const fn has_executed_buy_amount(&self) -> bool
Returns true if a buy execution amount is available.
Sourcepub const fn both_amounts_available(&self) -> bool
pub const fn both_amounts_available(&self) -> bool
Returns true if both executed sell and buy amounts are available.